#-*-coding:utf-8-*-
"""
    fonctions utils pour les appels sql
"""
from pyeole.process import system_code

def dump_sql_file(mysql_root_pwd, filename, database="", inject=''):
    """
        Dump un fichier .sql dans la base
    """
    mysql_cmd = ['mysql', '--defaults-file=/etc/mysql/debian.cnf', database]
    sql_code = inject
    sql_code += file(filename).read()
    return system_code(mysql_cmd, stdin=sql_code, container='mysql')

def dump_sql_file2(filename, database='', default_file='/etc/mysql/debian.cnf'):
    """
        Dump un fichier .sql dans la base
        En utilisant le fichier debian.cnf indiqué
    """
    mysql_cmd = ['mysql', '--defaults-file={}'.format(default_file), database]
    sql_code = file(filename).read()
    return system_code(mysql_cmd, stdin=sql_code, container='mysql')
